SafeAuthReq

Type Alias SafeAuthReq 

pub type SafeAuthReq = IpcReq;

Aliased Type

pub enum SafeAuthReq {
    Auth(AuthReq),
    Unregistered(Vec<u8>),
}

Variants



Auth(AuthReq)

Application authorisation request, used to obtain keypair/s the application shall sign the network requests with.



Unregistered(Vec<u8>)

Unregistered application request, used to obtain network bootstrapping information. Takes arbitrary user data as Vec<u8>, returns bootstrap information.