pub struct DbcTransaction {
pub inputs: Vec<BlindedInput>,
pub outputs: Vec<BlindedOutput>,
}Fields
inputs: Vec<BlindedInput>outputs: Vec<BlindedOutput>Implementations
Sourceimpl DbcTransaction
impl DbcTransaction
pub fn to_bytes(&self) -> Vec<u8> ⓘ
pub fn hash(&self) -> [u8; 32]
pub fn gen_message(&self) -> Vec<u8> ⓘ
Sourcepub fn verify(&self, blinded_amounts: &[RistrettoPoint]) -> Result<(), Error>
pub fn verify(&self, blinded_amounts: &[RistrettoPoint]) -> Result<(), Error>
Verify if the blinded amounts of the inputs, are the same as the set of blinded amounts you know of. This also checks that every input has the signature over this very tx, and that each public key of the inputs was the signer.